@@ -5,6 +5,9 @@ from .common import *
 from .logutil import *
 from .shared import Shared
 
+import importlib.resources
+from pathlib import Path
+
 
 import hail as hl
 from munch import Munch
@@ -25,17 +28,32 @@ class Executor:
 
         try:
             if hailLog:
-                hl.init(log=hailLog)
                 Shared.hailLog = hailLog
-                Log(f'Hail Log is written to {Shared.hailLog}')
             else:
-                hl.init()
-                Shared.hailLog = "NotAvailable (To Be Fixed)" #TBF
+                randomStr = ''.join(random.choice(string.ascii_uppercase + string.digits) for _ in range(8))
+                now = str(datetime.now().strftime("%Y%m%d-%H%M%S"))
+                Shared.hailLog = f'hail.{now}.{randomStr}.log'
 
-        
+            hl.init(log=Shared.hailLog)
 
-            workload.globConfig.hailLog = Shared.hailLog
+            with importlib.resources.path('cap', 'VERSION') as path:
+                Shared.capVersion = Path(path).read_text()
+            Shared.hailVersion = hl.version()
+            sc = hl.spark_context()
+            Shared.sparkVersion = sc.version
+
+            Log(f'CAP Version: {Shared.capVersion}')
+            Log(f'Hail Version: {Shared.hailVersion}')
+            Log(f'Spark Version {Shared.sparkVersion}')
+            Log(f'CAP Log {Shared.capLog}')
+            Log(f'Hail Log {Shared.hailLog}')
+
+
+            workload.globConfig.capVersion = Shared.capVersion
+            workload.globConfig.hailVersion = Shared.hailVersion
+            workload.globConfig.sparkVersion = Shared.sparkVersion
             workload.globConfig.capLog = Shared.capLog
+            workload.globConfig.hailLog = Shared.hailLog
             workload.Update()
 
             LogPrint("+++++++++++++++++++++++++++++++")
@@ -68,7 +86,8 @@ class Executor:
         workload.CheckStage(stage)  # Check the stage right before execution to make sure no dynamic error occurs
         LogPrint(f'Started')
         func = getattr(Operation, stage.spec.function)
-        stage.spec.logFile = Shared.logFile
+        stage.spec.capLog = Shared.capLog
+        stage.spec.hailLog = Shared.hailLog
         stage.spec.startTime = datetime.now()
         workload.ProcessLiveInputs(stage)
         func(stage)
