@@ -7,21 +7,31 @@ from datetime import datetime
 import random
 import string
 
-# Gets or creates a logger
 logger = logging.getLogger(__name__)
-# set log level
-logger.setLevel(logging.DEBUG)
-# define file handler and set formatter
-randomStr = ''.join(random.choice(string.ascii_uppercase + string.digits) for _ in range(8))
-now = str(datetime.now().strftime("%Y%m%d-%H%M%S"))
-fn = f'cap.{now}.{randomStr}.log.tsv'
-Shared.logFile = fn
-file_handler = logging.FileHandler(filename=fn,  mode='w')
-formatter = logging.Formatter('%(asctime)s\t%(levelname)s\t%(message)s')
-file_handler.setFormatter(formatter)
-# add file handler to logger
-logger.addHandler(file_handler)
-print(f'*** logger is initialised to write to {fn}')
+
+def InitLogger(capLog=None):
+
+    global logger
+    if capLog:
+        fileName = capLog
+    else:
+        randomStr = ''.join(random.choice(string.ascii_uppercase + string.digits) for _ in range(8))
+        now = str(datetime.now().strftime("%Y%m%d-%H%M%S"))
+        fileName = f'cap.{now}.{randomStr}.log.tsv'
+    
+    Shared.capLog = fileName
+
+    # Gets or creates a logger
+    # logger = logging.getLogger(__name__)
+    # set log level
+    logger.setLevel(logging.DEBUG)
+    # define file handler and set formatter
+    file_handler = logging.FileHandler(filename=Shared.capLog,  mode='w')
+    formatter = logging.Formatter('%(asctime)s\t%(levelname)s\t%(message)s')
+    file_handler.setFormatter(formatter)
+    # add file handler to logger
+    logger.addHandler(file_handler)
+    print(f'*** logger is initialised to write to {Shared.capLog}')
 
 # IMPORTANT You may not include other cap modules in this module
 
